summaryrefslogtreecommitdiff
path: root/editor
diff options
context:
space:
mode:
authorJuan Linietsky <reduzio@gmail.com>2021-08-23 20:36:48 -0300
committerGitHub <noreply@github.com>2021-08-23 20:36:48 -0300
commitaa3c3a9ebbc096bba9eda324b91acbb7f14a7b07 (patch)
tree5db9dc95f2d2d552a52349bd22578032727d682d /editor
parent0df9895eb755dba7ec9bd764c36fa873175bc256 (diff)
parent44d62a9f4b6ac892b1fb9b8998be4162409952e3 (diff)
Merge pull request #52036 from reduz/native-extension-argument-pointers
Implement NativeExtension pointer arguments
Diffstat (limited to 'editor')
-rw-r--r--editor/editor_help.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/editor/editor_help.cpp b/editor/editor_help.cpp
index 7df5f15a81..16151e36de 100644
--- a/editor/editor_help.cpp
+++ b/editor/editor_help.cpp
@@ -170,7 +170,7 @@ void EditorHelp::_add_type(const String &p_type, const String &p_enum) {
if (t.is_empty()) {
t = "void";
}
- bool can_ref = (t != "void") || !p_enum.is_empty();
+ bool can_ref = (t != "void" && t.find("*") == -1) || !p_enum.is_empty();
if (!p_enum.is_empty()) {
if (p_enum.get_slice_count(".") > 1) {
@@ -632,8 +632,8 @@ void EditorHelp::_update_doc() {
continue;
}
}
- // Ignore undocumented private.
- if (cd.methods[i].name.begins_with("_") && cd.methods[i].description.is_empty()) {
+ // Ignore undocumented non virtual private.
+ if (cd.methods[i].name.begins_with("_") && cd.methods[i].description.is_empty() && cd.methods[i].qualifiers.find("virtual") == -1) {
continue;
}
methods.push_back(cd.methods[i]);